/* Account.cc - source file for the mailfilter program
 * Copyright (c) 2000  Andreas Bauer <baueran@in.tum.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */


#include <vector>
#include <string>
#include <ctype.h>
#include "Account.hh"


namespace acc {

  Account::~Account() {
    vector<Header>::iterator curMessage = headers.begin();
    
    for(;curMessage != headers.end(); curMessage++)
      curMessage->lines.clear();

    headers.clear();
  }


  // Stores the _entire_ header of a message ('str') in the 'headers' variable, as well as the number of the message and its size
  // On success it returns 0. It returns -1 if for some reason the header string is unexpected in it's syntax or shape.
  int Account::storeMessageHeader(string str, int message, int size) {
    Header curHeader;
    Line curLine;
    curHeader.number = message;
    curHeader.size = size;

    int descrStart = 0, descrEnd = 0;
    int contentStart = 0, contentEnd = 0;
    string head = cleanString(str);

    // Extract information about "Subject: ...", "From: ..." and store it in messageHeaders.section
    for (int i = 0; i < (int)head.length(); i++) {
      // Description
      if ( isupper(head[i]) ) {
	descrStart = i;
	if ( (descrEnd = head.find(":", descrStart)) == -1)
	  return(-1);    // encountered malformed e-mail header. If that happens, Mailfilter needs fixing here, obviously.
	curLine.descr = head.substr(descrStart, (descrEnd - descrStart));

	// Content
	contentStart = descrEnd + 2;
	if ( (contentEnd = head.find("\n", contentStart)) == -1 ) // we only store the 1st line (in case there's more)
	  contentEnd = head.length();
	curLine.content = head.substr(contentStart, (contentEnd - contentStart));

	// Store header information for deleting
	if (curLine.descr.find("From") == 0)
	  curHeader.sender = curLine.content.c_str();
	else if (curLine.descr.find("Subject") == 0)
	  curHeader.subject = curLine.content.c_str();
	else if (curLine.descr.find("Date") == 0)
	  curHeader.date = curLine.content.c_str();

	// Move counter
	i = contentEnd;

	// Store the current line in the header (descr + content)
	curHeader.lines.push_back(curLine);
      }
      else { 
	if ( (i = head.find("\n", i)) == -1 )
	  i = head.length();
      }
    }
    
    // Store the header with all its lines
    headers.push_back(curHeader);

    return 0;
  }


  // Removes special line breaks from a string
  string Account::cleanString(string dirty) {
    for (int i = 0; i <= (int)dirty.length(); i++) {
      if ( (dirty[i] == '\r' && dirty[i+1] == '\n') || (dirty[i] == '\n' && dirty[i+1] == '\r') ) {
	dirty.replace(i, 2, "\n");
      }
    }
    
    return(dirty);
  }

}
