/* Account.hh - source file for the mailfilter program
 * Copyright (c) 2000  Andreas Bauer <baueran@in.tum.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */

#ifndef ACCOUNT_HH
#define ACCOUNT_HH

#include <string>
#include <vector>

namespace acc {

  // Structure of a _single_ line of a header
  typedef struct {
    string descr;
    string content;
  } Line;


  // Structure of the _entire_ header of an e-mail
  typedef struct {
    int number;
    int size;
    vector<Line> lines;

    // We store those values seperately so it's easier to log the information
    string sender; 
    string subject;
    string date;
  } Header;


  class Account {
  protected:
    string server;
    int port;
    string user;
    string pass;
    vector<Header> headers;                               // All e-mail headers of a mail box
    
    virtual int login() = 0;
    virtual int logout() = 0;
    virtual int deleteMessage(int) = 0;
    virtual int storeMessageHeader(string, int, int);     // string contains the entire header
                                                          // int#1 contains the number of the message
                                                          // int#2 is the message size in bytes
    virtual string cleanString(string);                   // Removes hidden line breaks and the like

  public:
    virtual ~Account() = 0;
    virtual int check() = 0;
  };
  
}

#endif
