/* PopAccount.cc - source file for the mailfilter program
 * Copyright (c) 2000  Andreas Bauer <baueran@in.tum.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */


#ifndef POPACCOUNT_HH
#define POPACCOUNT_HH

#include <string>
#include "Account.hh"
#include "Preferences.hh"
#include "Feedback.hh"

#define MAX_BYTES 512

namespace pop {

  class PopAccount: public acc::Account {
  private:
    // Variables from account
    string server;
    string user;
    string pass;
    int port;
    int mySocket;
    pref::Preferences* prefs;
    fb::Feedback* report;

    // Methods
    int login();
    int logout();
    int connectSocket();
    int disconnectSocket();
    int deleteMessage(int);
    int sendCommand(string);
    string receiveResult(string serverCommand = "irrelevant");
    string getWord(const string, int);
    bool serverResult(const string);
    bool isHeaderEnd(const string);

  public:
    PopAccount(string, string, string, int, pref::Preferences*);
    ~PopAccount();
    int check();
  };

  // Exceptions
  class IOException { };
  class ConnectionTimeOut { };
  class UnknownError { };
}  

#endif
